==> generator-jquery-plugin-0.0.2.tgz: package/generators/app/index.js <==
'use strict';
var yeoman = require('yeoman-generator');
var chalk = require('chalk');
var yosay = require('yosay');
var _ = require('lodash');
var answers;

module.exports = yeoman.generators.Base.extend({
  prompting: {
    basics: function () {
      var done = this.async();

      // Have Yeoman greet the user.
      this.log(yosay(
        'Welcome to the badass ' + chalk.red('JqueryPlugin') + ' generator!'
      ));

      var prompts = [{
        type: 'input',
        name: 'name',
        message: 'Plugin name?',
        default: _.kebabCase(this.appname)
      }, {
        type: 'input',
        name: 'version',
        message: 'What is the current version?',
        default: '0.0.0'
      }, {
        type: 'input',
        name: 'description',
        message: 'What will this plugin do?',
        default: 'jQuery plugin that does great things'
      }, {
        type: 'input',
        name: 'author',
        message: 'Who is the main author of this plugin?',
        default: 'Jimdo GmbH',
        store: true
      }, {
        type: 'input',
        name: 'authorHomepage',
        message: function(answers) {
          return 'What is the homepage of ' + answers.author + '?';
        },
        default: 'http://jimdo.com',
        store: true
      }, {
        type: 'input',
        name: 'keywords',
        message: 'Please provide keywords for bower.json and package.json (use comma)',
        default: 'jquery, plugin'
      }, {
        type: 'confirm',
        name: 'private',
        message: 'Is this a private project?',
        default: false,
        store: true
      }, {
        type: 'confirm',
        name: 'useGitHub',
        message: 'Use GitHub?',
        default: true
      }, {
        type: 'input',
        name: 'githubVendor',
        message: 'What User/Organisation will be used on GitHub?',
        default: 'Jimdo',
        store: true,
        when: function(answers) { return answers.useGitHub; }
      }, {
        type: 'input',
        name: 'githubName',
        message: 'What will be the repository name on GitHub?',
        default: function(answers) {
          return answers.name;
        },
        when: function(answers) { return answers.useGitHub; }
      }, {
        type: 'list',
        name: 'homepageType',
        message: 'Where should I point to when asked about the homepage?',
        choices: ['Repository', 'GitHub Page', 'Custom'],
        default: 0,
        when: function(answers) { return answers.useGitHub; }
      }, {
        type: 'input',
        name: 'homepage',
        message: 'What will be the homepage of this project?',
        default: 'http://example.org',
        when: function(answers) {
          return !answers.useGitHub || answers.homepageType === 'Custom';
        }
      }, {
        type: 'input',
        name: 'gitOrigin',
        message: 'What will be the git remote origin of this project?',
        default: function(answers) {
          return 'git@example.com:' + answers.name + '.git';
        },
        when: function(answers) {
          return !answers.useGitHub;
        }
      }, {
        type: 'confirm',
        name: 'useMIT',
        message: 'Append MIT License?',
        default: true
      }, {
        type: 'confirm',
        name: 'useStyles',
        message: 'Will there be CSS?',
        default: true
      }, {
        type: 'list',
        name: 'cssPreprocessor',
        message: 'Sass or Less?',
        choices: ['Less', 'Sass'],
        default: 1,
        when: function(answers) {
          return answers.useStyles;
        },
        store: true
      }];

      this.prompt(prompts, function(a) {
        answers = a;
        done();
      });
    }
  },

  configuring: {
    basics: function() {
      answers.year = new Date().getFullYear();
      answers.camelName = _.camelCase(answers.name);
    },
    keywordsList: function() {
      answers.keywords = _.trim(answers.keywords
        .split(',')
        .map(function(keyword) {
          return '"' + _.trim(keyword) + '"';
        }).join(',\n    '), '" ');
    },
    gitHubUrls: function() {
      if (answers.useGitHub) {
        var namespace = answers.githubVendor + '/' + answers.githubName;

        answers.gitOrigin = 'git@github.com:' + namespace + '.git';

        if (answers.homepageType === 'Repository') {
          answers.homepage = 'https://github.com/' + namespace;
        } else if (answers.homepageType === 'GitHub Page') {
          answers.homepage = [
            'http://',
            answers.githubVendor.toLowerCase(),
            '.github.io/',
            answers.githubName,
            '/'
          ].join('');
        } else if (answers.homepageType !== 'Custom') {
          throw new Error('unknown page type');
        }
      }
    }
  },

  writing: {
    package: function () {
      this.fs.copyTpl(
        this.templatePath('_package.json'),
        this.destinationPath('package.json'),
        answers
      );
      this.fs.copyTpl(
        this.templatePath('_bower.json'),
        this.destinationPath('bower.json'),
        answers
      );
    },
    dotfiles: function () {
      this.fs.copy(
        this.templatePath('.editorconfig'),
        this.destinationPath('.editorconfig')
      );
      this.fs.copy(
        this.templatePath('.gitignore'),
        this.destinationPath('.gitignore')
      );
      this.fs.copy(
        this.templatePath('.jscsrc'),
        this.destinationPath('.jscsrc')
      );
      this.fs.copy(
        this.templatePath('.jshintrc'),
        this.destinationPath('.jshintrc')
      );
      this.fs.copy(
        this.templatePath('test/.jshintrc'),
        this.destinationPath('test/.jshintrc')
      );
    },
    grunt: function () {
      this.fs.copy(
        this.templatePath('_gruntfile.js'),
        this.destinationPath('gruntfile.js')
      );
    },
    license: function() {
      if (answers.useMIT) {
        var licencePath = this.templatePath('licenses/mit');

        answers.licenceText = _.trim(_.template(
          this.fs.read(licencePath)
        )(answers)).split('\n').map(function(line) {
          return '> ' + line;
        }).join('\n');

        this.fs.copyTpl(
          licencePath,
          this.destinationPath('LICENSE'),
          answers
        );
      }
    },
    readme: function() {
      this.fs.copyTpl(
        this.templatePath('README.md'),
        this.destinationPath('README.md'),
        answers
      );
    },
    test: function() {
      this.fs.copyTpl(
        this.templatePath('test/unit/myPluginSpec.js'),
        this.destinationPath('test/unit/' + answers.camelName + 'Spec.js'),
        answers
      );
      this.fs.copy(
        this.templatePath('test/unit/SpecHelper.js'),
        this.destinationPath('test/unit/SpecHelper.js')
      );
    },
    demo: function() {
      this.fs.copyTpl(
        this.templatePath('demo/index.html'),
        this.destinationPath('demo/index.html'),
        answers
      );
      this.fs.copy(
        this.templatePath('demo/app.js'),
        this.destinationPath('demo/app.js')
      );
    },
    srcJs: function() {
      this.fs.copyTpl(
        this.templatePath('src/js/myPlugin.js'),
        this.destinationPath('src/js/' + answers.camelName + '.js'),
        answers
      );
    },
    styles: function() {
      var ext = 'css';
      var folder = 'css';
      if (answers.cssPreprocessor === 'Less') {
        ext = 'less';
        folder = 'less';
      } else if (answers.cssPreprocessor === 'Sass') {
        ext = 'scss';
        folder = 'sass';
      }
      this.fs.copy(
        this.templatePath('demo/style.css'),
        this.destinationPath('demo/style.' + ext)
      );

      if (!answers.useStyles) {
        return;
      }

      this.fs.copy(
        this.templatePath('src/css/style.css'),
        this.destinationPath('src/' + folder + '/style.' + ext)
      );
    }
  },

  install: function () {
    this.installDependencies();
  }
});

==> generator-jquery-plugin-0.0.3.tgz: package/generators/app/index.js <==
'use strict';
var yeoman = require('yeoman-generator');
var chalk = require('chalk');
var yosay = require('yosay');
var _ = require('lodash');
var answers;

module.exports = yeoman.generators.Base.extend({
  prompting: {
    basics: function () {
      var done = this.async();

      // Have Yeoman greet the user.
      this.log(yosay(
        'Welcome to the badass ' + chalk.red('JqueryPlugin') + ' generator!'
      ));

      var prompts = [{
        type: 'input',
        name: 'name',
        message: 'Plugin name?',
        default: _.kebabCase(this.appname)
      }, {
        type: 'input',
        name: 'version',
        message: 'What is the current version?',
        default: '0.0.0'
      }, {
        type: 'input',
        name: 'description',
        message: 'What will this plugin do?',
        default: 'jQuery plugin that does great things'
      }, {
        type: 'input',
        name: 'author',
        message: 'Who is the main author of this plugin?',
        default: 'Jimdo GmbH',
        store: true
      }, {
        type: 'input',
        name: 'authorHomepage',
        message: function(answers) {
          return 'What is the homepage of ' + answers.author + '?';
        },
        default: 'http://jimdo.com',
        store: true
      }, {
        type: 'input',
        name: 'keywords',
        message: 'Please provide keywords for bower.json and package.json (use comma)',
        default: 'jquery, plugin'
      }, {
        type: 'confirm',
        name: 'private',
        message: 'Is this a private project?',
        default: false,
        store: true
      }, {
        type: 'confirm',
        name: 'useGitHub',
        message: 'Use GitHub?',
        default: true
      }, {
        type: 'input',
        name: 'githubVendor',
        message: 'What User/Organisation will be used on GitHub?',
        default: 'Jimdo',
        store: true,
        when: function(answers) { return answers.useGitHub; }
      }, {
        type: 'input',
        name: 'githubName',
        message: 'What will be the repository name on GitHub?',
        default: function(answers) {
          return answers.name;
        },
        when: function(answers) { return answers.useGitHub; }
      }, {
        type: 'list',
        name: 'homepageType',
        message: 'Where should I point to when asked about the homepage?',
        choices: ['Repository', 'GitHub Page', 'Custom'],
        default: 0,
        when: function(answers) { return answers.useGitHub; }
      }, {
        type: 'input',
        name: 'homepage',
        message: 'What will be the homepage of this project?',
        default: 'http://example.org',
        when: function(answers) {
          return !answers.useGitHub || answers.homepageType === 'Custom';
        }
      }, {
        type: 'input',
        name: 'gitOrigin',
        message: 'What will be the git remote origin of this project?',
        default: function(answers) {
          return 'git@example.com:' + answers.name + '.git';
        },
        when: function(answers) {
          return !answers.useGitHub;
        }
      }, {
        type: 'confirm',
        name: 'useMIT',
        message: 'Append MIT License?',
        default: true
      }, {
        type: 'confirm',
        name: 'useStyles',
        message: 'Will there be CSS?',
        default: true
      }, {
        type: 'list',
        name: 'cssPreprocessor',
        message: 'Sass or Less?',
        choices: ['Less', 'Sass'],
        default: 1,
        when: function(answers) {
          return answers.useStyles;
        },
        store: true
      }];

      this.prompt(prompts, function(a) {
        answers = a;
        done();
      });
    }
  },

  configuring: {
    basics: function() {
      answers.year = new Date().getFullYear();
      answers.camelName = _.camelCase(answers.name);
    },
    keywordsList: function() {
      answers.keywords = _.trim(answers.keywords
        .split(',')
        .map(function(keyword) {
          return '"' + _.trim(keyword) + '"';
        }).join(',\n    '), '" ');
    },
    gitHubUrls: function() {
      if (answers.useGitHub) {
        var namespace = answers.githubVendor + '/' + answers.githubName;

        answers.gitOrigin = 'git@github.com:' + namespace + '.git';

        if (answers.homepageType === 'Repository') {
          answers.homepage = 'https://github.com/' + namespace;
        } else if (answers.homepageType === 'GitHub Page') {
          answers.homepage = [
            'http://',
            answers.githubVendor.toLowerCase(),
            '.github.io/',
            answers.githubName,
            '/'
          ].join('');
        } else if (answers.homepageType !== 'Custom') {
          throw new Error('unknown page type');
        }
      }
    }
  },

  writing: {
    package: function () {
      this.fs.copyTpl(
        this.templatePath('_package.json'),
        this.destinationPath('package.json'),
        answers
      );
      this.fs.copyTpl(
        this.templatePath('_bower.json'),
        this.destinationPath('bower.json'),
        answers
      );
    },
    dotfiles: function () {
      this.fs.copy(
        this.templatePath('.editorconfig'),
        this.destinationPath('.editorconfig')
      );
      this.fs.copy(
        this.templatePath('_gitignore'),
        this.destinationPath('.gitignore')
      );
      this.fs.copy(
        this.templatePath('.jscsrc'),
        this.destinationPath('.jscsrc')
      );
      this.fs.copy(
        this.templatePath('.jshintrc'),
        this.destinationPath('.jshintrc')
      );
      this.fs.copy(
        this.templatePath('test/.jshintrc'),
        this.destinationPath('test/.jshintrc')
      );
    },
    grunt: function () {
      this.fs.copy(
        this.templatePath('_gruntfile.js'),
        this.destinationPath('gruntfile.js')
      );
    },
    license: function() {
      if (answers.useMIT) {
        var licencePath = this.templatePath('licenses/mit');

        answers.licenceText = _.trim(_.template(
          this.fs.read(licencePath)
        )(answers)).split('\n').map(function(line) {
          return '> ' + line;
        }).join('\n');

        this.fs.copyTpl(
          licencePath,
          this.destinationPath('LICENSE'),
          answers
        );
      }
    },
    readme: function() {
      this.fs.copyTpl(
        this.templatePath('README.md'),
        this.destinationPath('README.md'),
        answers
      );
    },
    test: function() {
      this.fs.copyTpl(
        this.templatePath('test/unit/myPluginSpec.js'),
        this.destinationPath('test/unit/' + answers.camelName + 'Spec.js'),
        answers
      );
      this.fs.copy(
        this.templatePath('test/unit/SpecHelper.js'),
        this.destinationPath('test/unit/SpecHelper.js')
      );
    },
    demo: function() {
      this.fs.copyTpl(
        this.templatePath('demo/index.html'),
        this.destinationPath('demo/index.html'),
        answers
      );
      this.fs.copy(
        this.templatePath('demo/app.js'),
        this.destinationPath('demo/app.js')
      );
    },
    srcJs: function() {
      this.fs.copyTpl(
        this.templatePath('src/js/myPlugin.js'),
        this.destinationPath('src/js/' + answers.camelName + '.js'),
        answers
      );
    },
    styles: function() {
      var ext = 'css';
      var folder = 'css';
      if (answers.cssPreprocessor === 'Less') {
        ext = 'less';
        folder = 'less';
      } else if (answers.cssPreprocessor === 'Sass') {
        ext = 'scss';
        folder = 'sass';
      }
      this.fs.copy(
        this.templatePath('demo/style.css'),
        this.destinationPath('demo/style.' + ext)
      );

      if (!answers.useStyles) {
        return;
      }

      this.fs.copy(
        this.templatePath('src/css/style.css'),
        this.destinationPath('src/' + folder + '/style.' + ext)
      );
    }
  },

  install: function () {
    this.installDependencies();
  }
});
